@@ -22,7 +22,7 @@ end
 # This is a sanity check to make sure no one is attempting to install
 # this into an early Vagrant version.
 if Vagrant::VERSION < '1.5.0'
-  raise 'The Vagrant Libvirt plugin is only compatible with Vagrant 1.5+'
+  raise 'The Vagrant Libvirt plugin is only compatible with Vagrant 1.5+.'
 end
 
 # make sure base module class defined before loading plugin
