@@ -4,38 +4,38 @@ module VagrantPlugins
   module ProviderLibvirt
     module Action
       class HandleBoxImage
-
         @@lock = Mutex.new
 
-        def initialize(app, env)
+        def initialize(app, _env)
           @logger = Log4r::Logger.new('vagrant_libvirt::action::handle_box_image')
           @app = app
         end
 
         def call(env)
-
           # Verify box metadata for mandatory values.
           #
           # Virtual size has to be set for allocating space in storage pool.
           box_virtual_size = env[:machine].box.metadata['virtual_size']
-          if box_virtual_size == nil
-            raise Errors::NoBoxVirtualSizeSet
-          end
+          raise Errors::NoBoxVirtualSizeSet if box_virtual_size.nil?
 
           # Support qcow2 format only for now, but other formats with backing
           # store capability should be usable.
           box_format = env[:machine].box.metadata['format']
-          if box_format == nil
+          if box_format.nil?
             raise Errors::NoBoxFormatSet
           elsif box_format != 'qcow2'
             raise Errors::WrongBoxFormatSet
           end
 
           # Get config options
-          config   = env[:machine].provider_config
+          config = env[:machine].provider_config
           box_image_file = env[:machine].box.directory.join('box.img').to_s
-          env[:box_volume_name] = env[:machine].box.name.to_s.dup.gsub("/", "-VAGRANTSLASH-")
-          env[:box_volume_name] << "_vagrant_box_image_#{env[:machine].box.version.to_s rescue ''}.img"
+          env[:box_volume_name] = env[:machine].box.name.to_s.dup.gsub('/', '-VAGRANTSLASH-')
+          env[:box_volume_name] << "_vagrant_box_image_#{begin
+                                                           env[:machine].box.version.to_s
+                                                         rescue
+                                                           ''
+                                                         end}.img"
 
           # Override box_virtual_size
           if config.machine_virtual_size
@@ -60,15 +60,16 @@ module VagrantPlugins
           @@lock.synchronize do
             # Don't continue if image already exists in storage pool.
             break if ProviderLibvirt::Util::Collection.find_matching(
-              env[:machine].provider.driver.connection.volumes.all, env[:box_volume_name])
+              env[:machine].provider.driver.connection.volumes.all, env[:box_volume_name]
+            )
 
             # Box is not available as a storage pool volume. Create and upload
             # it as a copy of local box image.
             env[:ui].info(I18n.t('vagrant_libvirt.uploading_volume'))
 
             # Create new volume in storage pool
-            unless File.exists?(box_image_file)
-              raise Vagrant::Errors::BoxNotFound.new(name: env[:machine].box.name)
+            unless File.exist?(box_image_file)
+              raise Vagrant::Errors::BoxNotFound, name: env[:machine].box.name
             end
             box_image_size = File.size(box_image_file) # B
             message = "Creating volume #{env[:box_volume_name]}"
@@ -77,20 +78,21 @@ module VagrantPlugins
             begin
               fog_volume = env[:machine].provider.driver.connection.volumes.create(
                 name:         env[:box_volume_name],
-                allocation:   "#{box_image_size/1024/1024}M",
+                allocation:   "#{box_image_size / 1024 / 1024}M",
                 capacity:     "#{box_virtual_size}G",
                 format_type:  box_format,
-                pool_name:    config.storage_pool_name)
+                pool_name:    config.storage_pool_name
+              )
             rescue Fog::Errors::Error => e
               raise Errors::FogCreateVolumeError,
-                :error_message => e.message
+                    error_message: e.message
             end
 
             # Upload box image to storage pool
             ret = upload_image(box_image_file, config.storage_pool_name,
-              env[:box_volume_name], env) do |progress|
-                env[:ui].clear_line
-                env[:ui].report_progress(progress, box_image_size, false)
+                               env[:box_volume_name], env) do |progress|
+              env[:ui].clear_line
+              env[:ui].report_progress(progress, box_image_size, false)
             end
 
             # Clear the line one last time since the progress meter doesn't
@@ -120,10 +122,11 @@ module VagrantPlugins
 
           begin
             pool = env[:machine].provider.driver.connection.client.lookup_storage_pool_by_name(
-              pool_name)
+              pool_name
+            )
             volume = pool.lookup_volume_by_name(volume_name)
             stream = env[:machine].provider.driver.connection.client.stream
-            volume.upload(stream, offset=0, length=image_size)
+            volume.upload(stream, offset = 0, length = image_size)
 
             # Exception ProviderLibvirt::RetrieveError can be raised if buffer is
             # longer than length accepted by API send function.
@@ -131,10 +134,10 @@ module VagrantPlugins
             # TODO: How to find out if buffer is too large and what is the
             # length that send function will accept?
 
-            buf_size = 1024*250 # 250K
+            buf_size = 1024 * 250 # 250K
             progress = 0
             open(image_file, 'rb') do |io|
-              while (buff = io.read(buf_size)) do
+              while (buff = io.read(buf_size))
                 sent = stream.send buff
                 progress += sent
                 yield progress
@@ -142,14 +145,12 @@ module VagrantPlugins
             end
           rescue => e
             raise Errors::ImageUploadError,
-              :error_message => e.message
+                  error_message: e.message
           end
 
-          return progress == image_size
+          progress == image_size
         end
-
       end
     end
   end
 end
-
