@@ -51,6 +51,8 @@ module VagrantPlugins
       attr_accessor :management_network_mac
       attr_accessor :management_network_guest_ipv6
       attr_accessor :management_network_autostart
+      attr_accessor :management_network_pci_bus
+      attr_accessor :management_network_pci_slot
 
       # Default host prefix (alternative to use project folder name)
       attr_accessor :default_prefix
@@ -58,12 +60,14 @@ module VagrantPlugins
       # Domain specific settings used while creating new domain.
       attr_accessor :uuid
       attr_accessor :memory
+      attr_accessor :memory_backing
       attr_accessor :channel
       attr_accessor :cpus
       attr_accessor :cpu_mode
       attr_accessor :cpu_model
       attr_accessor :cpu_fallback
       attr_accessor :cpu_features
+      attr_accessor :cpu_topology
       attr_accessor :features
       attr_accessor :numa_nodes
       attr_accessor :loader
@@ -160,15 +164,19 @@ module VagrantPlugins
         @management_network_mac  = UNSET_VALUE
         @management_network_guest_ipv6 = UNSET_VALUE
         @management_network_autostart = UNSET_VALUE
+        @management_network_pci_slot = UNSET_VALUE
+        @management_network_pci_bus = UNSET_VALUE
 
         # Domain specific settings.
         @uuid              = UNSET_VALUE
         @memory            = UNSET_VALUE
+        @memory_backing    = UNSET_VALUE
         @cpus              = UNSET_VALUE
         @cpu_mode          = UNSET_VALUE
         @cpu_model         = UNSET_VALUE
         @cpu_fallback      = UNSET_VALUE
         @cpu_features      = UNSET_VALUE
+        @cpu_topology      = UNSET_VALUE
         @features          = UNSET_VALUE
         @numa_nodes        = UNSET_VALUE
         @loader            = UNSET_VALUE
@@ -279,26 +287,27 @@ module VagrantPlugins
       end
 
       def _generate_numa
-        raise 'NUMA nodes must be a factor of CPUs' if @cpus % @numa_nodes != 0
+        @numa_nodes.collect { |x|
+          # Perform some validation of cpu values
+          unless x[:cpus] =~ /^\d+-\d+$/
+            raise 'numa_nodes[:cpus] must be in format "integer-integer"'
+          end
 
-        if @memory % @numa_nodes != 0
-          raise 'NUMA nodes must be a factor of memory'
+          # Convert to KiB
+          x[:memory] = x[:memory].to_i * 1024
+        }
+
+        # Grab the value of the last @numa_nodes[:cpus] and verify @cpus matches
+        # Note: [:cpus] is zero based and @cpus is not, so we need to +1
+        last_cpu = @numa_nodes.last[:cpus]
+        last_cpu = last_cpu.scan(/\d+$/)[0]
+        last_cpu = last_cpu.to_i + 1
+
+        if @cpus != last_cpu.to_i
+          raise 'The total number of numa_nodes[:cpus] must equal config.cpus'
         end
 
-        numa = []
-
-        (1..@numa_nodes).each do |node|
-          numa_cpu_start = (@cpus / @numa_nodes) * (node - 1)
-          numa_cpu_end = (@cpus / @numa_nodes) * node - 1
-          numa_cpu = Array(numa_cpu_start..numa_cpu_end).join(',')
-          numa_mem = @memory / @numa_nodes
-
-          numa.push(id: node,
-                    cpu: numa_cpu,
-                    mem: numa_mem)
-        end
-
-        @numa_nodes = numa
+        @numa_nodes
       end
 
       def cpu_feature(options = {})
@@ -312,6 +321,35 @@ module VagrantPlugins
                            policy: options[:policy])
       end
 
+      def cputopology(options = {})
+        if options[:sockets].nil? || options[:cores].nil? || options[:threads].nil?
+          raise 'CPU topology must have all of sockets, cores and threads specified'
+        end
+
+        if @cpu_topology == UNSET_VALUE
+          @cpu_topology = {}
+        end
+
+        @cpu_topology[:sockets] = options[:sockets]
+        @cpu_topology[:cores] = options[:cores]
+        @cpu_topology[:threads] = options[:threads]        
+      end
+
+      def memorybacking(option, config = {})
+        case option
+        when :source
+          raise 'Source type must be specified' if config[:type].nil?
+        when :access
+          raise 'Access mode must be specified' if config[:mode].nil?
+        when :allocation
+          raise 'Allocation mode must be specified' if config[:mode].nil?
+        end
+
+        @memory_backing = [] if @memory_backing == UNSET_VALUE
+        @memory_backing.push(name: option,
+                             config: config)
+      end
+
       def input(options = {})
         if options[:type].nil? || options[:bus].nil?
           raise 'Input type AND bus must be specified'
@@ -561,6 +599,8 @@ module VagrantPlugins
         @management_network_mac = nil if @management_network_mac == UNSET_VALUE
         @management_network_guest_ipv6 = 'yes' if @management_network_guest_ipv6 == UNSET_VALUE
         @management_network_autostart = false if @management_network_autostart == UNSET_VALUE
+        @management_network_pci_bus = nil if @management_network_pci_bus == UNSET_VALUE
+        @management_network_pci_slot = nil if @management_network_pci_slot == UNSET_VALUE
 
         # generate a URI if none is supplied
         @uri = _generate_uri if @uri == UNSET_VALUE
@@ -568,6 +608,7 @@ module VagrantPlugins
         # Domain specific settings.
         @uuid = '' if @uuid == UNSET_VALUE
         @memory = 512 if @memory == UNSET_VALUE
+        @memory_backing = [] if @memory_backing == UNSET_VALUE
         @cpus = 1 if @cpus == UNSET_VALUE
         @cpu_mode = 'host-model' if @cpu_mode == UNSET_VALUE
         @cpu_model = if (@cpu_model == UNSET_VALUE) && (@cpu_mode == 'custom')
@@ -575,6 +616,7 @@ module VagrantPlugins
                      elsif @cpu_mode != 'custom'
                        ''
           end
+        @cpu_topology = {} if @cpu_topology == UNSET_VALUE
         @cpu_fallback = 'allow' if @cpu_fallback == UNSET_VALUE
         @cpu_features = [] if @cpu_features == UNSET_VALUE
         @features = ['acpi','apic','pae'] if @features == UNSET_VALUE
@@ -599,7 +641,7 @@ module VagrantPlugins
            @graphics_passwd == UNSET_VALUE
           @graphics_passwd = nil
         end
-        @graphics_port = 5900 if @graphics_port == UNSET_VALUE
+        @graphics_port = -1 if @graphics_port == UNSET_VALUE
         @graphics_ip = '127.0.0.1' if @graphics_ip == UNSET_VALUE
         @video_type = 'cirrus' if @video_type == UNSET_VALUE
         @video_vram = 9216 if @video_vram == UNSET_VALUE
@@ -674,8 +716,14 @@ module VagrantPlugins
         end
 
         machine.config.vm.networks.each do |_type, opts|
-          if opts[:mac] && opts[:mac].downcase! && !(opts[:mac] =~ /\A([0-9a-f]{2}:){5}([0-9a-f]{2})\z/)
-            errors << "Configured NIC MAC '#{opts[:mac]}' is not in 'xx:xx:xx:xx:xx:xx' format"
+          if opts[:mac]
+            opts[:mac].downcase!
+            if opts[:mac] =~ /\A([0-9a-f]{12})\z/
+              opts[:mac] = opts[:mac].scan(/../).join(':')
+            end
+            unless opts[:mac] =~ /\A([0-9a-f]{2}:){5}([0-9a-f]{2})\z/
+              errors << "Configured NIC MAC '#{opts[:mac]}' is not in 'xx:xx:xx:xx:xx:xx' or 'xxxxxxxxxxxx' format"
+            end
           end
         end
 
