@@ -1,3 +1,6 @@
+require 'coveralls'
+Coveralls.wear!
+
 require 'vagrant-libvirt'
 require 'support/environment_helper'
 require 'vagrant-spec/unit'
